@@ -8,8 +8,8 @@ class Site(scotus_slip.Site):
         super(Site, self).__init__(*args, **kwargs)
         self.court_id = self.__module__
         self.back_scrape_iterable = range(5, int(self.yy) + 1)
-        self.precedential = 'In-chambers'
-        self.court = 'in-chambers'
+        self.precedential = "In-chambers"
+        self.court = "in-chambers"
 
     def set_url(self):
-        self.url = '%s/%s.aspx' % (self.url_base, self.court)
\ No newline at end of file
+        self.url = "%s/%s.aspx" % (self.url_base, self.court)
