@@ -24,46 +24,53 @@ from juriscraper.lib.string_utils import clean_if_py3
 
 
 class Site(OpinionSite):
-
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
-        self.court = 'Appellate+Term,+1st+Dept'
+        self.court = "Appellate+Term,+1st+Dept"
         self.interval = 365
-        self.back_scrape_iterable = [i.date() for i in rrule(
-            DAILY,
-            interval=self.interval,
-            dtstart=date(2004, 1, 1),
-            until=date(2016, 1, 1),
-        )]
+        self.back_scrape_iterable = [
+            i.date()
+            for i in rrule(
+                DAILY,
+                interval=self.interval,
+                dtstart=date(2004, 1, 1),
+                until=date(2016, 1, 1),
+            )
+        ]
 
-        self.url = 'http://iapps.courts.state.ny.us/lawReporting/Search'
+        self.url = "http://iapps.courts.state.ny.us/lawReporting/Search"
 
         self.parameters = {
-            'rbOpinionMotion': 'opinion',
-            'Pty': '',
-            'and_or': 'and',
-            'dtStartDate': (date.today() - timedelta(days=30)).strftime("%m/%d/%Y"),
-            'dtEndDate': date.today().strftime("%m/%d/%Y"),
-            'court': self.court,
-            'docket': '',
-            'judge': '',
-            'slipYear': '',
-            'slipNo': '',
-            'OffVol': '',
-            'OffPage': '',
-            'fullText': '',
-            'and_or2': 'and',
-            'Submit': 'Find',
-            'hidden1': '',
-            'hidden2': ''
-
+            "rbOpinionMotion": "opinion",
+            "Pty": "",
+            "and_or": "and",
+            "dtStartDate": (date.today() - timedelta(days=30)).strftime(
+                "%m/%d/%Y"
+            ),
+            "dtEndDate": date.today().strftime("%m/%d/%Y"),
+            "court": self.court,
+            "docket": "",
+            "judge": "",
+            "slipYear": "",
+            "slipNo": "",
+            "OffVol": "",
+            "OffPage": "",
+            "fullText": "",
+            "and_or2": "and",
+            "Submit": "Find",
+            "hidden1": "",
+            "hidden2": "",
         }
 
         self.court_id = self.__module__
-        self.method = 'POST'
+        self.method = "POST"
         self.base_path = '//tr[td[5]//a][td[7][contains(., "Opinion")]]'  # Any element with a link on the 5th column
-        self.href_js = re.compile(r"funcNewWindow\(\\{0,1}'(.*\.htm)\\{0,1}'\)")
-        self.href_standard = re.compile(r"http(s)?://www.nycourts.gov/(.*).htm")
+        self.href_js = re.compile(
+            r"funcNewWindow\(\\{0,1}'(.*\.htm)\\{0,1}'\)"
+        )
+        self.href_standard = re.compile(
+            r"http(s)?://www.nycourts.gov/(.*).htm"
+        )
         self.uses_selenium = True
 
     def _download(self, request_dict={}):
@@ -76,11 +83,11 @@ class Site(OpinionSite):
 
         self.set_cookies()
         logger.info("Using cookies: %s" % self.cookies)
-        request_dict.update({'cookies': self.cookies})
+        request_dict.update({"cookies": self.cookies})
 
         html__ = super(Site, self)._download(request_dict)
         i = 0
-        while not html__.xpath('//table') and i < 10:
+        while not html__.xpath("//table") and i < 10:
             add_delay(20, 5)
             html__ = super(Site, self)._download(request_dict)
             i += 1
@@ -90,14 +97,16 @@ class Site(OpinionSite):
     def _get_case_names(self):
         case_names = []
         for element in self.html.xpath(self.base_path):
-            case_names.append(''.join(x.strip() for x in element.xpath('./td[1]//text()')))
+            case_names.append(
+                "".join(x.strip() for x in element.xpath("./td[1]//text()"))
+            )
         return case_names
 
     def _get_download_urls(self):
         download_urls = []
         for element in self.html.xpath(self.base_path):
-            url = ''
-            for href in element.xpath('./td[5]//@href'):
+            url = ""
+            for href in element.xpath("./td[5]//@href"):
                 href = clean_if_py3(href)
                 # Check for newer standard href
                 match = self.href_standard.match(href)
@@ -114,52 +123,62 @@ class Site(OpinionSite):
 
     def _get_case_dates(self):
         case_dates = []
-        for element in self.html.xpath("{}/td[2]//text()".format(self.base_path)):
-            case_dates.append(datetime.strptime(element.strip(), '%m/%d/%Y'))
+        for element in self.html.xpath(
+            "{}/td[2]//text()".format(self.base_path)
+        ):
+            case_dates.append(datetime.strptime(element.strip(), "%m/%d/%Y"))
         return case_dates
 
     def _get_precedential_statuses(self):
-        return ['Published'] * len(self.case_names)
+        return ["Published"] * len(self.case_names)
 
     def _get_docket_numbers(self):
         docket_numbers = []
         for element in self.html.xpath(self.base_path):
-            docket_numbers.append(''.join(x.strip() for x in element.xpath('./td[5]//text()')))
+            docket_numbers.append(
+                "".join(x.strip() for x in element.xpath("./td[5]//text()"))
+            )
         return docket_numbers
 
     def _get_judges(self):
         judges = []
-        for element in self.html.xpath('{}/td[6]'.format(self.base_path, )):
-            judges.append(''.join(x.strip() for x in element.xpath('.//text()')))
+        for element in self.html.xpath("{}/td[6]".format(self.base_path,)):
+            judges.append(
+                "".join(x.strip() for x in element.xpath(".//text()"))
+            )
         return judges
 
     def _get_neutral_citations(self):
         neutral_citations = []
-        for element in self.html.xpath('{}/td[4]'.format(self.base_path, )):
-            neutral_citations.append(''.join(x.strip() for x in element.xpath('.//text()')))
+        for element in self.html.xpath("{}/td[4]".format(self.base_path,)):
+            neutral_citations.append(
+                "".join(x.strip() for x in element.xpath(".//text()"))
+            )
         return neutral_citations
 
     def _download_backwards(self, d):
         self.crawl_date = d
-        self.method = 'POST'
+        self.method = "POST"
         self.parameters = {
-            'rbOpinionMotion': 'opinion',
-            'Pty': '',
-            'and_or': 'and',
-            'dtStartDate': (d - timedelta(days=self.interval)).strftime("%m/%d/%Y"),
-            'dtEndDate': d.strftime("%m/%d/%Y"),
-            'court': self.court,
-            'docket': '',
-            'judge': '',
-            'slipYear': '',
-            'slipNo': '',
-            'OffVol': '',
-            'OffPage': '',
-            'fullText': '',
-            'and_or2': 'and',
-            'Submit': 'Find',
-            'hidden1': '',
-            'hidden2': ''
+            "rbOpinionMotion": "opinion",
+            "Pty": "",
+            "and_or": "and",
+            "dtStartDate": (d - timedelta(days=self.interval)).strftime(
+                "%m/%d/%Y"
+            ),
+            "dtEndDate": d.strftime("%m/%d/%Y"),
+            "court": self.court,
+            "docket": "",
+            "judge": "",
+            "slipYear": "",
+            "slipNo": "",
+            "OffVol": "",
+            "OffPage": "",
+            "fullText": "",
+            "and_or2": "and",
+            "Submit": "Find",
+            "hidden1": "",
+            "hidden2": "",
         }
         self.html = self._download()
         if self.html is not None:
@@ -190,9 +209,7 @@ class Site(OpinionSite):
     @staticmethod
     def cleanup_content(content):
         tree = html.fromstring(content)
-        core_element = tree.xpath('//partyblock')[0]
+        core_element = tree.xpath("//partyblock")[0]
         return html.tostring(
-            core_element,
-            pretty_print=True,
-            encoding='unicode'
+            core_element, pretty_print=True, encoding="unicode"
         )
