@@ -16,24 +16,30 @@ from juriscraper.lib.cookie_utils import normalize_cookies
 class Site(OpinionSite):
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
-        self.url = 'http://www.ca5.uscourts.gov/electronic-case-filing/case-information/current-opinions'
+        self.url = "http://www.ca5.uscourts.gov/electronic-case-filing/case-information/current-opinions"
         self.court_id = self.__module__
         self.interval = 5
         self.case_date = datetime.today()
-        self.back_scrape_iterable = [i.date() for i in rrule(
-            DAILY,
-            interval=self.interval,  # Every interval days
-            dtstart=date(1992, 5, 14),
-            until=date(2015, 1, 1),
-        )]
+        self.back_scrape_iterable = [
+            i.date()
+            for i in rrule(
+                DAILY,
+                interval=self.interval,  # Every interval days
+                dtstart=date(1992, 5, 14),
+                until=date(2015, 1, 1),
+            )
+        ]
         self.uses_selenium = True
 
     def _download(self, request_dict={}):
         if self.test_mode_enabled():
             html_tree_list = [
-                super(Site, self)._download(request_dict=request_dict)]
-            self.records_nr = len(html_tree_list[0].xpath(
-                "//tr[contains(concat('', @id, ''), 'ctl00_Body_C010_ctl00_ctl00_radGridOpinions_ctl00')]")
+                super(Site, self)._download(request_dict=request_dict)
+            ]
+            self.records_nr = len(
+                html_tree_list[0].xpath(
+                    "//tr[contains(concat('', @id, ''), 'ctl00_Body_C010_ctl00_ctl00_radGridOpinions_ctl00')]"
+                )
             )
             return html_tree_list
         else:
@@ -57,40 +63,61 @@ class Site(OpinionSite):
                 )
             )
 
-            start_date = driver.find_element_by_id("ctl00_Body_C010_ctl00_ctl00_startDate_dateInput")
-            start_date.send_keys((self.case_date - timedelta(days=self.interval)).strftime("%m/%d/%Y"))
+            start_date = driver.find_element_by_id(
+                "ctl00_Body_C010_ctl00_ctl00_startDate_dateInput"
+            )
+            start_date.send_keys(
+                (self.case_date - timedelta(days=self.interval)).strftime(
+                    "%m/%d/%Y"
+                )
+            )
 
-            end_date = driver.find_element_by_id("ctl00_Body_C010_ctl00_ctl00_endDate_dateInput")
+            end_date = driver.find_element_by_id(
+                "ctl00_Body_C010_ctl00_ctl00_endDate_dateInput"
+            )
             end_date.send_keys(self.case_date.strftime("%m/%d/%Y"))
-            #driver.save_screenshot('%s.png' % self.case_date)
+            # driver.save_screenshot('%s.png' % self.case_date)
 
-            submit = driver.find_element_by_id("Body_C010_ctl00_ctl00_btnSearch")
+            submit = driver.find_element_by_id(
+                "Body_C010_ctl00_ctl00_btnSearch"
+            )
             submit.click()
 
             WebDriverWait(driver, 30).until(
-                EC.presence_of_element_located((By.ID, "ctl00_Body_C010_ctl00_ctl00_radGridOpinions_ctl00"))
+                EC.presence_of_element_located(
+                    (
+                        By.ID,
+                        "ctl00_Body_C010_ctl00_ctl00_radGridOpinions_ctl00",
+                    )
+                )
             )
             self.status = 200
             # driver.save_screenshot('%s.png' % self.case_date)
 
             try:
                 nr_of_pages = driver.find_element_by_xpath(
-                    '//div[contains(concat(" ", @class, " "), "rgInfoPart")]/strong[2]')
+                    '//div[contains(concat(" ", @class, " "), "rgInfoPart")]/strong[2]'
+                )
                 records_nr = driver.find_element_by_xpath(
-                    '//div[contains(concat(" ", @class, " "), "rgInfoPart")]/strong[1]')
+                    '//div[contains(concat(" ", @class, " "), "rgInfoPart")]/strong[1]'
+                )
                 self.records_nr = int(records_nr.text)
                 nr_of_pages = int(nr_of_pages.text)
             except NoSuchElementException:
                 try:
-                    self.records_nr = len(driver.find_elements_by_xpath(
-                        "//tr[contains(concat('', @id, ''), 'ctl00_Body_C010_ctl00_ctl00_radGridOpinions_ctl00')]")
+                    self.records_nr = len(
+                        driver.find_elements_by_xpath(
+                            "//tr[contains(concat('', @id, ''), 'ctl00_Body_C010_ctl00_ctl00_radGridOpinions_ctl00')]"
+                        )
                     )
                     nr_of_pages = 1
                 except NoSuchElementException:
                     driver.quit()
                     return []
             html_pages = []
-            logger.info("records: {}, pages: {}".format(self.records_nr, nr_of_pages))
+            logger.info(
+                "records: {}, pages: {}".format(self.records_nr, nr_of_pages)
+            )
             if nr_of_pages == 1:
                 text = driver.page_source
                 driver.quit()
@@ -98,25 +125,26 @@ class Site(OpinionSite):
                 html_tree = html.fromstring(text)
                 html_tree.make_links_absolute(self.url)
 
-                remove_anchors = lambda url: url.split('#')[0]
+                remove_anchors = lambda url: url.split("#")[0]
                 html_tree.rewrite_links(remove_anchors)
                 html_pages.append(html_tree)
             else:
-                logger.info("Paginating through %s pages of results." %
-                            nr_of_pages)
+                logger.info(
+                    "Paginating through %s pages of results." % nr_of_pages
+                )
                 logger.info("  Getting page 1")
                 text = driver.page_source
 
                 html_tree = html.fromstring(text)
                 html_tree.make_links_absolute(self.url)
 
-                remove_anchors = lambda url: url.split('#')[0]
+                remove_anchors = lambda url: url.split("#")[0]
                 html_tree.rewrite_links(remove_anchors)
                 html_pages.append(html_tree)
 
                 for i in range(nr_of_pages - 1):
                     logger.info("  Getting page %s" % (i + 2))
-                    next_page = driver.find_element_by_class_name('rgPageNext')
+                    next_page = driver.find_element_by_class_name("rgPageNext")
                     next_page.click()
                     driver.implicitly_wait(5)
 
@@ -125,7 +153,7 @@ class Site(OpinionSite):
                     html_tree = html.fromstring(text)
                     html_tree.make_links_absolute(self.url)
 
-                    remove_anchors = lambda url: url.split('#')[0]
+                    remove_anchors = lambda url: url.split("#")[0]
                     html_tree.rewrite_links(remove_anchors)
                     html_pages.append(html_tree)
                 driver.quit()
@@ -158,7 +186,7 @@ class Site(OpinionSite):
                 path = "id('ctl00_Body_C010_ctl00_ctl00_radGridOpinions_ctl00__{n}')/td[3]/text()".format(
                     n=record
                 )
-                yield datetime.strptime(html_tree.xpath(path)[0], '%m/%d/%Y')
+                yield datetime.strptime(html_tree.xpath(path)[0], "%m/%d/%Y")
 
     def _get_docket_numbers(self):
         for html_tree in self.html:
@@ -176,20 +204,24 @@ class Site(OpinionSite):
                 path = "id('ctl00_Body_C010_ctl00_ctl00_radGridOpinions_ctl00__{n}')/td[5]/text()".format(
                     n=record
                 )
-                yield 'Unpublished' if 'unpub' in html_tree.xpath(path)[0] else 'Published'
+                yield "Unpublished" if "unpub" in html_tree.xpath(path)[
+                    0
+                ] else "Published"
 
     @staticmethod
     def _get_opinion_count(html_tree):
-        return int(html_tree.xpath(
-            "count(//tr[contains(concat('', @id, ''), 'ctl00_Body_C010_ctl00_ctl00_radGridOpinions_ctl00')])")
+        return int(
+            html_tree.xpath(
+                "count(//tr[contains(concat('', @id, ''), 'ctl00_Body_C010_ctl00_ctl00_radGridOpinions_ctl00')])"
+            )
         )
 
     def _download_backwards(self, d):
         self.case_date = d
-        logger.info("Running backscraper with date range: %s to %s" % (
-            self.case_date - timedelta(days=self.interval),
-            self.case_date,
-        ))
+        logger.info(
+            "Running backscraper with date range: %s to %s"
+            % (self.case_date - timedelta(days=self.interval), self.case_date,)
+        )
         self.html = self._download()
         if self.html is not None:
             # Setting status is important because it prevents the download
